@@ -22,6 +22,7 @@
 
 #include "articleformatter.h"
 #include "akregator_export.h"
+#include <QUrl>
 class QPaintDevice;
 namespace Akregator {
 class GrantleeViewFormatter;
@@ -42,8 +43,8 @@ private:
     QUrl m_imageDir;
     QString m_DefaultThemePath;
     class SummaryVisitor;
-    SummaryVisitor *m_summaryVisitor;
-    GrantleeViewFormatter *mGrantleeViewFormatter;
+    SummaryVisitor *m_summaryVisitor = nullptr;
+    GrantleeViewFormatter *mGrantleeViewFormatter = nullptr;
 };
 }
 #endif // DEFAULTNORMALVIEWFORMATTER_H
